@@ -1,10 +1,9 @@
-from django import forms as django_forms
-from django.db.models.related import RelatedObject
+from django.db.models.fields.related import ManyToOneRel
 from django.conf import settings
 
 from django_filters import FilterSet, Filter
 from django_filters.filterset import get_model_field
-import floppyforms as forms
+from django.contrib.gis import forms
 
 from .settings import app_settings, API_SRID
 from .widgets import HiddenGeometryWidget
@@ -12,12 +11,12 @@ from .widgets import HiddenGeometryWidget
 
 class PolygonFilter(Filter):
 
-    field_class = forms.gis.PolygonField
+    field_class = forms.PolygonField
 
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('name', app_settings['GEOM_FIELD_NAME'])
         kwargs.setdefault('widget', HiddenGeometryWidget)
-        kwargs.setdefault('lookup_type', 'intersects')
+        kwargs.setdefault('lookup_expr', 'intersects')
         super(PolygonFilter, self).__init__(*args, **kwargs)
 
 
@@ -33,7 +32,7 @@ class PythonPolygonFilter(PolygonFilter):
         for o in qs.all():
             geom = getattr(o, self.name)
             if geom and geom.valid and not geom.empty:
-                if getattr(geom, self.lookup_type)(value):
+                if getattr(geom, self.lookup_expr)(value):
                     filtered.append(o.pk)
             else:
                 filtered.append(o.pk)
@@ -53,13 +52,13 @@ class BaseMapEntityFilterSet(FilterSet):
         """
         for fieldname in self.base_filters.keys():
             field = self.form.fields[fieldname]
-            if isinstance(field, django_forms.MultiValueField):
+            if isinstance(field, forms.MultiValueField):
                 for i, widget in enumerate(field.widget.widgets):
                     self.__set_placeholder(field.fields[i], widget)
-            elif isinstance(field, django_forms.ChoiceField):
+            elif isinstance(field, forms.ChoiceField):
                 field.empty_label = field.label
                 self.__set_placeholder(field, field.widget)
-            elif isinstance(field, django_forms.NullBooleanField):
+            elif isinstance(field, forms.NullBooleanField):
                 choices = [(u'1', field.label)] + field.widget.choices[1:]
                 field.widget.choices = choices
                 self.__set_placeholder(field, field.widget)
@@ -77,7 +76,7 @@ class BaseMapEntityFilterSet(FilterSet):
     def add_filter(cls, name, filter_=None):
         field = get_model_field(cls._meta.model, name)
         if filter_ is None:
-            if isinstance(field, RelatedObject):
+            if isinstance(field, ManyToOneRel):
                 filter_ = cls.filter_for_reverse_field(field, name)
             else:
                 filter_ = cls.filter_for_field(field, name)
