@@ -1,14 +1,13 @@
 import logging
-from urlparse import urlparse
 from subprocess import check_output
 
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.contrib.auth.signals import user_logged_in
 from django.db import DatabaseError
+from django.utils.six.moves.urllib.parse import urlparse
 
-from . import app_settings
-
+from .settings import app_settings
 
 logger = logging.getLogger(__name__)
 
@@ -20,15 +19,15 @@ LOCALHOST = check_output(['hostname', '-I']).split() + ['127.0.0.1']
 def get_internal_user():
     if not hasattr(get_internal_user, 'instance'):
         username = app_settings['INTERNAL_USER']
-        try:
-            User = get_user_model()
-            internal_user = User.objects.get(username=username)
-        except User.DoesNotExist:
-            internal_user = User(username=username,
-                                 password=settings.SECRET_KEY)
-            internal_user.is_active = True
-            internal_user.is_staff = False
-            internal_user.save()
+        User = get_user_model()
+
+        internal_user, created = User.objects.get_or_create(
+            username=username,
+            defaults={'password': settings.SECRET_KEY,
+                      'is_active': True,
+                      'is_staff': False}
+        )
+
         get_internal_user.instance = internal_user
     return get_internal_user.instance
 
@@ -46,19 +45,29 @@ class AutoLoginMiddleware(object):
     django-screamshot, or deployed OpenId, or whatever. But this was a lot easier.
     """
     def process_request(self, request):
+        if "HTTP_X_FORWARDED_FOR" in request.META:
+            request.META["HTTP_X_PROXY_REMOTE_ADDR"] = request.META["REMOTE_ADDR"]
+            parts = request.META["HTTP_X_FORWARDED_FOR"].split(",", 1)
+            request.META["REMOTE_ADDR"] = parts[0]
+
+        useragent = request.META.get('HTTP_USER_AGENT', '')
+        if useragent:
+            request.META['HTTP_USER_AGENT'] = useragent.replace('FrontendTest', '')
+        is_running_tests = ('FrontendTest' in useragent or
+                            getattr(settings, 'TEST', False))
+
         user = getattr(request, 'user', None)
-        if user and user.is_anonymous():
+        if user and user.is_anonymous() and not is_running_tests:
             remoteip = request.META.get('REMOTE_ADDR')
             remotehost = request.META.get('REMOTE_HOST')
-            is_running_tests = ('FrontendTest' in request.META.get('HTTP_USER_AGENT', '') or
-                                getattr(settings, 'TEST', False))
-            is_localhost = (remoteip in LOCALHOST or remotehost == 'localhost')
-            is_auto_allowed = (is_localhost or
-                               (remoteip and remoteip in (CONVERSION_SERVER_HOST,
-                                                          CAPTURE_SERVER_HOST)) or
-                               (remotehost and remotehost in (CONVERSION_SERVER_HOST,
-                                                              CAPTURE_SERVER_HOST)))
-            if is_auto_allowed and not is_running_tests:
+
+            is_auto_allowed = (
+                (remoteip in LOCALHOST or remotehost == 'localhost') or
+                (remoteip and remoteip in (CONVERSION_SERVER_HOST, CAPTURE_SERVER_HOST)) or
+                (remotehost and remotehost in (CONVERSION_SERVER_HOST, CAPTURE_SERVER_HOST))
+            )
+
+            if is_auto_allowed:
                 logger.info("Auto-login for %s/%s" % (remoteip, remotehost))
                 user = get_internal_user()
                 try:
