@@ -1,19 +1,20 @@
 import os
 import math
+from PIL import Image, ImageDraw, ImageFont
 
+from django.contrib.contenttypes.fields import GenericRelation
 from django.db import models
 from django.db.utils import OperationalError
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import FieldError, ObjectDoesNotExist
-from django.core.urlresolvers import NoReverseMatch
+from django.urls import reverse, NoReverseMatch
 from django.contrib import auth
 from django.contrib.admin.models import LogEntry as BaseLogEntry
 from django.contrib.admin.models import ADDITION, CHANGE, DELETION
 from django.utils.formats import localize
 from django.utils.timezone import utc
 from django.utils.translation import ugettext_lazy as _
-from paperclip.models import Attachment
 from rest_framework import permissions as rest_permissions
 
 from mapentity.templatetags.mapentity_tags import humanize_timesince
@@ -29,14 +30,16 @@ ENTITY_FORMAT_LIST = "format_list"
 ENTITY_DETAIL = "detail"
 ENTITY_MAPIMAGE = "mapimage"
 ENTITY_DOCUMENT = "document"
+ENTITY_MARKUP = "markup"
 ENTITY_CREATE = "add"
 ENTITY_UPDATE = "update"
 ENTITY_DELETE = "delete"
+ENTITY_UPDATE_GEOM = "update_geom"
 
 ENTITY_KINDS = (
     ENTITY_LAYER, ENTITY_LIST, ENTITY_JSON_LIST,
-    ENTITY_FORMAT_LIST, ENTITY_DETAIL, ENTITY_MAPIMAGE, ENTITY_DOCUMENT, ENTITY_CREATE,
-    ENTITY_UPDATE, ENTITY_DELETE
+    ENTITY_FORMAT_LIST, ENTITY_DETAIL, ENTITY_MAPIMAGE, ENTITY_DOCUMENT, ENTITY_MARKUP, ENTITY_CREATE,
+    ENTITY_UPDATE, ENTITY_DELETE, ENTITY_UPDATE_GEOM
 )
 
 ENTITY_PERMISSION_CREATE = 'add'
@@ -44,11 +47,13 @@ ENTITY_PERMISSION_READ = 'read'
 ENTITY_PERMISSION_UPDATE = 'change'
 ENTITY_PERMISSION_DELETE = 'delete'
 ENTITY_PERMISSION_EXPORT = 'export'
+ENTITY_PERMISSION_UPDATE_GEOM = 'change_geom'
 
 ENTITY_PERMISSIONS = (
     ENTITY_PERMISSION_CREATE,
     ENTITY_PERMISSION_READ,
     ENTITY_PERMISSION_UPDATE,
+    ENTITY_PERMISSION_UPDATE_GEOM,
     ENTITY_PERMISSION_DELETE,
     ENTITY_PERMISSION_EXPORT
 )
@@ -66,11 +71,15 @@ class MapEntityRestPermissions(rest_permissions.DjangoModelPermissions):
     }
 
 
-class MapEntityMixin(object):
+class MapEntityMixin(models.Model):
+    attachments = GenericRelation(settings.PAPERCLIP_ATTACHMENT_MODEL)
 
     _entity = None
     capture_map_image_waitfor = '.leaflet-tile-loaded'
 
+    class Meta:
+        abstract = True
+
     @classmethod
     def get_create_label(cls):
         name = cls._meta.verbose_name
@@ -84,12 +93,13 @@ class MapEntityMixin(object):
         operations = {
             ENTITY_CREATE: ENTITY_PERMISSION_CREATE,
             ENTITY_UPDATE: ENTITY_PERMISSION_UPDATE,
+            ENTITY_UPDATE_GEOM: ENTITY_PERMISSION_UPDATE_GEOM,
             ENTITY_DELETE: ENTITY_PERMISSION_DELETE,
-
             ENTITY_DETAIL: ENTITY_PERMISSION_READ,
             ENTITY_LAYER: ENTITY_PERMISSION_READ,
             ENTITY_LIST: ENTITY_PERMISSION_READ,
             ENTITY_JSON_LIST: ENTITY_PERMISSION_READ,
+            ENTITY_MARKUP: ENTITY_PERMISSION_READ,
 
             ENTITY_FORMAT_LIST: ENTITY_PERMISSION_EXPORT,
             ENTITY_MAPIMAGE: ENTITY_PERMISSION_EXPORT,
@@ -137,65 +147,50 @@ class MapEntityMixin(object):
         super(MapEntityMixin, self).delete(*args, **kwargs)
 
     @classmethod
-    @models.permalink
     def get_layer_url(cls):
-        return (cls._entity.url_name(ENTITY_LAYER), )
+        return reverse(cls._entity.url_name(ENTITY_LAYER))
 
     @classmethod
-    @models.permalink
     def get_list_url(cls):
-        return (cls._entity.url_name(ENTITY_LIST), )
+        return reverse(cls._entity.url_name(ENTITY_LIST))
 
     @classmethod
-    @models.permalink
     def get_jsonlist_url(cls):
-        return (cls._entity.url_name(ENTITY_JSON_LIST), )
+        return reverse(cls._entity.url_name(ENTITY_JSON_LIST))
 
     @classmethod
-    @models.permalink
     def get_format_list_url(cls):
-        return (cls._entity.url_name(ENTITY_FORMAT_LIST), )
+        return reverse(cls._entity.url_name(ENTITY_FORMAT_LIST))
 
     @classmethod
-    @models.permalink
     def get_add_url(cls):
-        return (cls._entity.url_name(ENTITY_CREATE), )
+        return reverse(cls._entity.url_name(ENTITY_CREATE))
 
     def get_absolute_url(self):
         return self.get_detail_url()
 
     @classmethod
-    @models.permalink
     def get_generic_detail_url(cls):
-        return (cls._entity.url_name(ENTITY_DETAIL), [str(0)])
+        return reverse(cls._entity.url_name(ENTITY_DETAIL), args=[str(0)])
 
-    @models.permalink
     def get_detail_url(self):
-        return (self._entity.url_name(ENTITY_DETAIL), [str(self.pk)])
+        return reverse(self._entity.url_name(ENTITY_DETAIL), args=[str(self.pk)])
 
     @property
     def map_image_url(self):
         return self.get_map_image_url()
 
-    @models.permalink
     def get_map_image_url(self):
-        return (self._entity.url_name(ENTITY_MAPIMAGE), [str(self.pk)])
+        return reverse(self._entity.url_name(ENTITY_MAPIMAGE), args=[str(self.pk)])
 
-    @models.permalink
     def get_document_url(self):
-        return (self._entity.url_name(ENTITY_DOCUMENT), [str(self.pk)])
+        return reverse(self._entity.url_name(ENTITY_DOCUMENT), args=[str(self.pk)])
 
-    @models.permalink
     def get_update_url(self):
-        return (self._entity.url_name(ENTITY_UPDATE), [str(self.pk)])
+        return reverse(self._entity.url_name(ENTITY_UPDATE), args=[str(self.pk)])
 
-    @models.permalink
     def get_delete_url(self):
-        return (self._entity.url_name(ENTITY_DELETE), [str(self.pk)])
-
-    @property
-    def attachments(self):
-        return Attachment.objects.attachments_for_object(self)
+        return reverse(self._entity.url_name(ENTITY_DELETE), args=[str(self.pk)])
 
     def get_map_image_extent(self, srid=API_SRID):
         fieldname = app_settings['GEOM_FIELD_NAME']
@@ -204,12 +199,18 @@ class MapEntityMixin(object):
         return obj.extent
 
     def prepare_map_image(self, rooturl):
-        if self.get_geom() is None:
-            return True
         path = self.get_map_image_path()
         # Do nothing if image is up-to-date
         if is_file_newer(path, self.get_date_update()):
             return False
+        if self.get_geom() is None:
+            size = app_settings['MAP_CAPTURE_SIZE']
+            image = Image.new('RGB', (size, size), color=(192, 192, 192))
+            font = ImageFont.truetype('/usr/share/fonts/truetype/liberation/LiberationSans-Regular.ttf', 24)
+            draw = ImageDraw.Draw(image)
+            draw.text((10, 10), "This object has no geometry", font=font, fill=(0, 0, 0))
+            image.save(path)
+            return True
         url = smart_urljoin(rooturl, self.get_detail_url())
         extent = self.get_map_image_extent(3857)
         length = max(extent[2] - extent[0], extent[3] - extent[1])
@@ -222,14 +223,15 @@ class MapEntityMixin(object):
             size = math.ceil(length * 1.1 * 256 * 2 ** zoom / CIRCUM)
         else:
             size = app_settings['MAP_CAPTURE_SIZE']
-        capture_map_image(url, path, size=size, waitfor=self.capture_map_image_waitfor)
+        printcontext = self.get_printcontext() if hasattr(self, 'get_printcontext') else None
+        capture_map_image(url, path, size=size, waitfor=self.capture_map_image_waitfor, printcontext=printcontext)
         return True
 
     def get_map_image_path(self):
         basefolder = os.path.join(settings.MEDIA_ROOT, 'maps')
         if not os.path.exists(basefolder):
             os.makedirs(basefolder)
-        return os.path.join(basefolder, '%s-%s.png' % (self._meta.module_name, self.pk))
+        return os.path.join(basefolder, '%s-%s.png' % (self._meta.model_name, self.pk))
 
     def get_attributes_html(self, request):
         return extract_attributes_html(self.get_detail_url(), request)
@@ -270,6 +272,7 @@ class LogEntry(MapEntityMixin, BaseLogEntry):
 
     class Meta:
         proxy = True
+        app_label = 'mapentity'
 
     @property
     def action_flag_display(self):
@@ -286,7 +289,7 @@ class LogEntry(MapEntityMixin, BaseLogEntry):
 
     @property
     def object_display(self):
-        model_str = unicode(self.content_type)
+        model_str = u"{}".format(self.content_type)
         try:
             obj = self.get_edited_object()
             assert obj._entity, 'Unregistered model %s' % model_str
