@@ -1,14 +1,14 @@
 import re
+from importlib import import_module
 import inspect
 import logging
 from collections import OrderedDict
 
-from django.db.utils import ProgrammingError
 from django.db import DEFAULT_DB_ALIAS
-from django.utils.importlib import import_module
+from django.db.utils import ProgrammingError
 from django.utils.translation import ugettext as _
 from django.views.generic.base import View
-from django.conf.urls import patterns, url, include
+from django.conf.urls import url, include
 from django.contrib.contenttypes.models import ContentType
 from django.contrib import auth
 from django.contrib.auth.models import Permission
@@ -17,9 +17,9 @@ from rest_framework import routers as rest_routers
 from rest_framework import serializers as rest_serializers
 from mapentity import models as mapentity_models
 from mapentity.middleware import get_internal_user
-from mapentity import app_settings
+from mapentity.settings import app_settings
 
-from paperclip import models as paperclip_models
+from paperclip.settings import get_attachment_model
 
 
 logger = logging.getLogger(__name__)
@@ -40,17 +40,16 @@ class MapEntityOptions(object):
         self.model = model
         self.label = model._meta.verbose_name_plural
         self.app_label = model._meta.app_label
-        self.module_name = model._meta.module_name
-        self.modelname = self.module_name
-        self.icon = 'images/%s.png' % self.module_name
-        self.icon_small = 'images/%s-16.png' % self.module_name
-        self.icon_big = 'images/%s-96.png' % self.module_name
+        self.modelname = model._meta.model_name
+        self.icon = 'images/%s.png' % self.modelname
+        self.icon_small = 'images/%s-16.png' % self.modelname
+        self.icon_big = 'images/%s-96.png' % self.modelname
 
         self.rest_router = rest_routers.DefaultRouter(trailing_slash=False)
 
         # Can't do reverse right now, URL not setup yet
-        self.url_list = '%s:%s_%s' % (self.app_label, self.module_name, 'list')
-        self.url_add = '%s:%s_%s' % (self.app_label, self.module_name, 'add')
+        self.url_list = '%s:%s_%s' % (self.app_label, self.modelname, 'list')
+        self.url_add = '%s:%s_%s' % (self.app_label, self.modelname, 'add')
 
     def scan_views(self):
         """
@@ -118,10 +117,10 @@ class MapEntityOptions(object):
                 serializer_class = _serializer
             rest_viewset = dynamic_viewset
 
-        self.rest_router.register(self.modelname + 's', rest_viewset)
+        self.rest_router.register(self.modelname + 's', rest_viewset, base_name=self.modelname)
 
         # Returns Django URL patterns
-        return patterns('', *self.__view_classes_to_url(*picked))
+        return self.__view_classes_to_url(*picked)
 
     def get_serializer(self):
         _model = self.model
@@ -131,6 +130,7 @@ class MapEntityOptions(object):
                 model = _model
                 geo_field = app_settings['GEOM_FIELD_NAME']
                 id_field = 'id'
+                exclude = []
 
         return Serializer
 
@@ -148,6 +148,7 @@ class MapEntityOptions(object):
             mapentity_models.ENTITY_CREATE: r'^{modelname}/add/$',
             mapentity_models.ENTITY_UPDATE: r'^{modelname}/edit/(?P<pk>\d+)/$',
             mapentity_models.ENTITY_DELETE: r'^{modelname}/delete/(?P<pk>\d+)/$',
+            mapentity_models.ENTITY_MARKUP: r'^{modelname}/markup/(?P<pk>\d+)/$',
         }
         if app_settings['MAPENTITY_WEASYPRINT']:
             kind_to_urlpath[mapentity_models.ENTITY_DOCUMENT] = r'^document/{modelname}-(?P<pk>\d+).pdf$'
@@ -169,7 +170,7 @@ class MapEntityOptions(object):
 
     def url_shortname(self, kind):
         assert kind in mapentity_models.ENTITY_KINDS
-        return '%s_%s' % (self.module_name, kind)
+        return '%s_%s' % (self.modelname, kind)
 
     def url_name(self, kind):
         assert kind in mapentity_models.ENTITY_KINDS
@@ -189,10 +190,10 @@ class Registry(object):
 
         # Ignore models from not installed apps
         if not model._meta.installed:
-            return ()
+            return []
         # Register once only
         if model in self.registry:
-            return ()
+            return []
 
         if options is None:
             options = MapEntityOptions(model)
@@ -211,7 +212,7 @@ class Registry(object):
 
         try:
             self.content_type_ids.append(model.get_content_type_id())
-        except ProgrammingError:
+        except (RuntimeError, ProgrammingError):
             pass  # Content types table is not yet synced
 
         return options.scan_views()
@@ -221,6 +222,9 @@ class Registry(object):
         return self.registry.values()
 
 
+registry = Registry()
+
+
 def create_mapentity_model_permissions(model):
     """
     Create all the necessary permissions for the specified model.
@@ -276,7 +280,7 @@ def create_mapentity_model_permissions(model):
             logger.info("Added permission %s to internal user %s" % (codename,
                                                                      internal_user))
 
-    attachmenttype = ContentType.objects.db_manager(db).get_for_model(paperclip_models.Attachment)
+    attachmenttype = ContentType.objects.db_manager(db).get_for_model(get_attachment_model())
     read_perm = dict(codename='read_attachment', content_type=attachmenttype)
     if not internal_user.user_permissions.filter(**read_perm).exists():
         permission = perms_manager.get(**read_perm)
