@@ -27,15 +27,18 @@ app_settings = dict({
     'ACTION_HISTORY_LENGTH': 20,
     'ANONYMOUS_VIEWS_PERMS': tuple(),
     'GEOJSON_LAYERS_CACHE_BACKEND': 'default',
+    'GEOJSON_PRECISION': None,
     'SERVE_MEDIA_AS_ATTACHMENT': True,
     'SENDFILE_HTTP_HEADER': None,
     'DRF_API_URL_PREFIX': r'^api/',
+    'MAPENTITY_WEASYPRINT': False,
 }, **getattr(settings, 'MAPENTITY_CONFIG', {}))
 
 
 TINYMCE_DEFAULT_CONFIG = {
     'theme': 'advanced',
-    'theme_advanced_buttons1': 'bold,italic,forecolor,separator,bullist,numlist,link,media,separator,undo,redo,separator,cleanup,code',
+    'theme_advanced_buttons1': 'bold,italic,forecolor,separator,bullist,numlist,link,media,separator,undo,redo,\
+separator,cleanup,code',
     'theme_advanced_buttons2': '',
     'theme_advanced_buttons3': '',
     'theme_advanced_statusbar_location': 'bottom',
