@@ -23,10 +23,15 @@ L.ObjectsLayer = L.GeoJSON.extend({
 
         var onFeatureParse = function (geojson, layer) {
             this._mapObjects(geojson, layer);
-            if (this._onEachFeature) this._onEachFeature(geojson, layer);
+            if (this._onEachFeature) {
+                this._onEachFeature(geojson, layer);
+            }
         };
         var pointToLayer = function (geojson, latlng) {
             if (this._pointToLayer) return this._pointToLayer(geojson, latlng);
+            if (geojson.geometry.type === "Point" && geojson.properties.radius) {
+                return new L.Circle(latlng, geojson.properties.radius);
+            }
             return new L.CircleMarker(latlng);
         };
         this._onEachFeature = options.onEachFeature;
@@ -39,16 +44,31 @@ L.ObjectsLayer = L.GeoJSON.extend({
         this.options.styles = L.Util.extend({}, this.options.styles);
         this.options.styles['default'] = L.Util.extend({}, this.options.style);
 
-        // Highlight on mouse over
+
+        // Highlight on mouse over, using global events
         if (this.options.highlight) {
             this.on('mouseover', function(e) {
-                this.highlight(this.getPk(e.layer));
+                var pk = this.getPk(e.layer);
+                $(window).trigger('entity:mouseover', {pk: pk, modelname: options.modelname});
             }, this);
             this.on('mouseout', function(e) {
-                if (e.layer.properties)
-                    this.highlight(this.getPk(e.layer), false);
+                var pk = this.getPk(e.layer);
+                $(window).trigger('entity:mouseout', {pk: pk, modelname: options.modelname});
             }, this);
         }
+        // Listen to external events, such as those fired from this layer, and
+        // from DOM (in detail pages, see ``hoverable`` CSS selector)
+        $(window).on('entity:mouseover', L.Util.bind(function (e, data) {
+            if (data.modelname == options.modelname) {
+                this.highlight(data.pk, true);
+            }
+        }, this));
+        $(window).on('entity:mouseout', L.Util.bind(function (e, data) {
+            if (data.modelname == options.modelname) {
+                this.highlight(data.pk, false);
+            }
+        }, this));
+
 
         // Optionnaly make them clickable
         if (this.options.objectUrl) {
@@ -79,12 +99,17 @@ L.ObjectsLayer = L.GeoJSON.extend({
         this._objects[pk] = this._current_objects[pk] = layer;
         layer.properties = geojson.properties;
         this.indexLayer(layer);
+
+        // Fix highlighting of multi-part geometries:
+        // Propagate GeoJSON properties to sub-layers
+        if (typeof layer.eachLayer == 'function') {
+            layer.eachLayer(function (l) {
+                l.properties = geojson.properties;
+            });
+        }
     },
 
-    load: function (url, force) {
-        if (!!force && url.indexOf("?") != -1) {
-            url += '?_u=' + (new Date().getTime());
-        }
+    load: function (url) {
         var jsonLoad = function (data) {
             var features = jQuery.grep(data.features, function(obj, i) {
                 return obj.geometry !== null;
@@ -172,12 +197,11 @@ L.ObjectsLayer = L.GeoJSON.extend({
         if (!layer) return;
 
         if (on) {
-            layer._defaultStyle = layer._defaultStyle || this.options.styles['default'];
             layer.setStyle(this.options.styles.highlight);
             this.fire('highlight', {layer: layer});
         }
         else {
-            layer.setStyle(layer._defaultStyle);
+            this.resetStyle(layer);
         }
     },
 
