@@ -1,17 +1,18 @@
-import os
 import datetime
+import os
 
 from django import template
 from django.conf import settings
 from django.contrib.gis.geos import GEOSGeometry
-from django.template.base import TemplateDoesNotExist
-from django.db.models.fields.related import FieldDoesNotExist
+from django.core.exceptions import FieldDoesNotExist
+from django.template import Context
+from django.template.exceptions import TemplateDoesNotExist
+from django.utils import six
 from django.utils.timezone import utc
 from django.utils.translation import ugettext, ungettext
 
 from ..helpers import alphabet_enumeration
 
-
 register = template.Library()
 
 
@@ -32,9 +33,10 @@ class SmartIncludeNode(template.Node):
         result = ""
         for module in apps:
             try:
-                template_name = "%(module)s/%(module)s_%(viewname)s_fragment.html" % {'viewname': viewname, 'module': module}
+                template_name = "%(module)s/%(module)s_%(viewname)s_fragment.html" % {'viewname': viewname,
+                                                                                      'module': module}
                 t = template.loader.get_template(template_name)
-                result += t.render(context)
+                result += t.render(Context.flatten(context))
             except TemplateDoesNotExist:
                 pass
         return result
@@ -53,7 +55,7 @@ def do_smart_include(parser, token):
 
 @register.filter
 def latlngbounds(obj):
-    if obj is None or isinstance(obj, basestring):
+    if obj is None or isinstance(obj, six.string_types):
         return 'null'
     if isinstance(obj, GEOSGeometry):
         extent = obj.extent
@@ -71,7 +73,7 @@ def field_verbose_name(obj, field):
         a = getattr(obj, '%s_verbose_name' % field)
         if a is None:
             raise
-        return unicode(a)
+        return u"{}".format(a)
 
 
 @register.simple_tag()
@@ -81,6 +83,13 @@ def media_static_fallback(media_file, static_file, *args, **kwarg):
     return os.path.join(settings.STATIC_URL, static_file)
 
 
+@register.simple_tag()
+def media_static_fallback_path(media_file, static_file, *args, **kwarg):
+    if os.path.exists(os.path.join(settings.MEDIA_ROOT, media_file)):
+        return os.path.join(settings.MEDIA_ROOT, media_file)
+    return os.path.join(settings.STATIC_ROOT, static_file)
+
+
 @register.filter(name='timesince')
 def humanize_timesince(date):
     """
