@@ -1,17 +1,23 @@
 from .generic import (
     Convert,
-    MapEntityLayer,
     MapEntityList,
-    MapEntityJsonList,
     MapEntityFormat,
     MapEntityMapImage,
     MapEntityDocument,
+    MapEntityDocumentBase,
+    MapEntityDocumentOdt,
+    MapEntityDocumentWeasyprint,
+    MapEntityMarkupWeasyprint,
     DocumentConvert,
     MapEntityCreate,
     MapEntityDetail,
     MapEntityUpdate,
     MapEntityDelete,
-    MAPENTITY_GENERIC_VIEWS,
+)
+from .api import (
+    MapEntityLayer,
+    MapEntityJsonList,
+    MapEntityViewSet
 )
 from .mixins import (
     HttpJSONResponse,
@@ -22,28 +28,48 @@ from .mixins import (
 from .base import (
     handler403,
     handler404,
-    handler500,
-    serve_secure_media,
+    serve_attachment,
     JSSettings,
     map_screenshot,
     history_delete,
 )
 from .logentry import LogEntryList
 
+
+MAPENTITY_GENERIC_VIEWS = [
+    MapEntityLayer,
+    MapEntityList,
+    MapEntityJsonList,
+    MapEntityFormat,
+    MapEntityMapImage,
+    MapEntityDocument,
+    MapEntityMarkupWeasyprint,
+    MapEntityCreate,
+    MapEntityDetail,
+    MapEntityUpdate,
+    MapEntityDelete,
+]
+
 __all__ = [
     'Convert',
-    'MapEntityLayer',
     'MapEntityList',
-    'MapEntityJsonList',
     'MapEntityFormat',
     'MapEntityMapImage',
     'MapEntityDocument',
+    'MapEntityDocumentBase',
+    'MapEntityDocumentOdt',
+    'MapEntityDocumentWeasyprint',
+    'MapEntityMarkupWeasyprint',
     'DocumentConvert',
     'MapEntityCreate',
     'MapEntityDetail',
     'MapEntityUpdate',
     'MapEntityDelete',
 
+    'MapEntityLayer',
+    'MapEntityJsonList',
+    'MapEntityViewSet',
+
     'HttpJSONResponse',
     'JSONResponseMixin',
     'LastModifiedMixin',
@@ -53,7 +79,7 @@ __all__ = [
     'handler403',
     'handler404',
     'handler500',
-    'serve_secure_media',
+    'serve_attachment',
     'JSSettings',
     'map_screenshot',
     'convert',
