@@ -7,7 +7,7 @@ from rest_framework import viewsets
 from rest_framework_gis.serializers import GeoFeatureModelSerializer
 
 from mapentity import models as mapentity_models
-from ..settings import API_SRID
+from ..settings import API_SRID, app_settings
 from ..decorators import (view_cache_response_content, view_cache_latest,
                           view_permission_required)
 from .. import serializers as mapentity_serializers
@@ -26,6 +26,7 @@ class MapEntityLayer(FilterListMixin, ModelViewMixin, GeoJSONLayerView):
 
     force2d = True
     srid = API_SRID
+    precision = app_settings.get('GEOJSON_PRECISION')
 
     def __init__(self, *args, **kwargs):
         super(MapEntityLayer, self).__init__(*args, **kwargs)
@@ -69,6 +70,11 @@ class MapEntityJsonList(JSONResponseMixin, BaseListView, ListView):
                                     fields=self.columns,
                                     model=self.get_model())
 
+    @view_permission_required()
+    @view_cache_latest()
+    def dispatch(self, *args, **kwargs):
+        return super(BaseListView, self).dispatch(*args, **kwargs)
+
 
 class MapEntityViewSet(viewsets.ModelViewSet):
     def get_serializer_class(self):
@@ -76,6 +82,7 @@ class MapEntityViewSet(viewsets.ModelViewSet):
         renderer, media_type = self.perform_content_negotiation(self.request)
         if getattr(renderer, 'format') == 'geojson':
             class Serializer(serializer, GeoFeatureModelSerializer):
-                pass
+                class Meta(serializer.Meta):
+                    pass
             return Serializer
         return serializer
