@@ -1,36 +1,32 @@
-# -*- coding: utf-8 -*-
-import os
-import sys
-import urllib2
-import logging
-import traceback
-from datetime import datetime
+from __future__ import unicode_literals
+
 import json
+import logging
 import mimetypes
+import os
+from datetime import datetime
+import re
 
 from django.conf import settings
 from django.contrib.auth.decorators import login_required
 from django.contrib.gis.db.models import GeometryField
-from django.http import (HttpResponse, HttpResponseBadRequest,
-                         HttpResponseServerError, Http404)
 from django.core.exceptions import PermissionDenied
-from django.core.urlresolvers import reverse
+from django.urls import reverse
+from django.http import (HttpResponse, HttpResponseBadRequest, Http404)
+from django.shortcuts import get_object_or_404
+from django.utils.six.moves.urllib.parse import quote
+from django.views import static
+from django.views.decorators.csrf import csrf_exempt
+from django.views.decorators.http import require_http_methods
 from django.views.defaults import page_not_found, permission_denied
 from django.views.generic.base import TemplateView
-from django.views import static
-from django.views.decorators.http import require_http_methods
-from django.views.decorators.csrf import csrf_exempt
-from django.template import RequestContext, Context, loader
-from django.shortcuts import get_object_or_404
-from django.db.models.loading import get_model
-
-from ..decorators import view_permission_required
-from ..settings import app_settings, _MAP_STYLES
-from ..helpers import capture_image
-from .mixins import JSONResponseMixin, FilterListMixin, ModelViewMixin
+from paperclip.settings import get_attachment_permission, get_attachment_model
 
 from mapentity import models as mapentity_models
-
+from .mixins import JSONResponseMixin, FilterListMixin, ModelViewMixin
+from ..decorators import view_permission_required
+from ..helpers import capture_image
+from ..settings import app_settings, _MAP_STYLES
 
 logger = logging.getLogger(__name__)
 
@@ -43,46 +39,22 @@ def handler404(request, template_name='mapentity/404.html'):
     return page_not_found(request, template_name)
 
 
-def handler500(request, template_name='mapentity/500.html'):
-    """
-    500 error handler which tries to use a RequestContext - unless an error
-    is raised, in which a normal Context is used with just the request
-    available.
-
-    Templates: `500.html`
-    Context: None
-    """
-    # Try returning using a RequestContext
-    try:
-        context = RequestContext(request)
-    except:
-        logger.warn('Error getting RequestContext for ServerError page.')
-        context = Context({'request': request})
-    e, name, tb = sys.exc_info()
-    context['exception'] = repr(name)
-    context['stack'] = "\n".join(traceback.format_tb(tb))
-    t = loader.get_template(template_name)
-    response = t.render(context)
-    return HttpResponseServerError(response)
-
-
-def serve_attachment(request, path, app_label, model_name, pk):
+def serve_attachment(request, path):
     """
     Serve media/ for authorized users only, since it can contain sensitive
     information (uploaded documents)
     """
-    model = get_model(app_label, model_name)
-    if not model:
+    original_path = re.sub(r'\.\d+x\d+_q\d+(_crop)?\.(jpg|png|jpeg)$', '', path, count=1, flags=re.IGNORECASE)
+    attachment = get_object_or_404(get_attachment_model(), attachment_file=original_path)
+    obj = attachment.content_object
+    if not issubclass(obj._meta.model, mapentity_models.MapEntityMixin):
         raise Http404
-    if not issubclass(model, mapentity_models.MapEntityMixin):
-        raise Http404
-    obj = get_object_or_404(model, pk=pk)
     if not obj.is_public():
         if not request.user.is_authenticated():
             raise PermissionDenied
-        if not request.user.has_perm('paperclip.read_attachment'):
+        if not request.user.has_perm(get_attachment_permission('read_attachment')):
             raise PermissionDenied
-        if not request.user.has_perm('%s.read_%s' % (app_label, model_name)):
+        if not request.user.has_perm('{}.read_{}'.format(obj._meta.app_label, obj._meta.model_name)):
             raise PermissionDenied
 
     content_type, encoding = mimetypes.guess_type(path)
@@ -107,6 +79,7 @@ class JSSettings(JSONResponseMixin, TemplateView):
     Likely to be overriden. Contains only necessary stuff
     for mapentity.
     """
+
     def get_context_data(self):
         dictsettings = {}
         dictsettings['debug'] = settings.DEBUG
@@ -117,7 +90,7 @@ class JSSettings(JSONResponseMixin, TemplateView):
 
         # URLs
         root_url = app_settings['ROOT_URL']
-        root_url = root_url if root_url.endswith('/') else root_url + '/'
+        root_url = root_url if root_url.endswith('/') else '{}/'.format(root_url)
         dictsettings['urls'] = {}
         dictsettings['urls']['root'] = root_url
 
@@ -130,13 +103,16 @@ class JSSettings(JSONResponseMixin, TemplateView):
         options = MapEntityOptions(ModelName)
 
         dictsettings['urls']['static'] = settings.STATIC_URL
-        dictsettings['urls']['layer'] = root_url + options._url_path(mapentity_models.ENTITY_LAYER)[1:-1]
-        dictsettings['urls']['detail'] = root_url + 'modelname/0/'
-        dictsettings['urls']['format_list'] = root_url + options._url_path(mapentity_models.ENTITY_FORMAT_LIST)[1:-1]
+        dictsettings['urls']['layer'] = '{}{}'.format(root_url, options._url_path(mapentity_models.ENTITY_LAYER)[1:-1])
+        dictsettings['urls']['detail'] = '{}modelname/0/'.format(root_url)
+        dictsettings['urls']['format_list'] = '{}{}'.format(
+            root_url, options._url_path(mapentity_models.ENTITY_FORMAT_LIST)[1:-1]
+        )
         dictsettings['urls']['screenshot'] = reverse("mapentity:map_screenshot")
 
         # Useful for JS calendars
-        dictsettings['date_format'] = settings.DATE_INPUT_FORMATS[0].replace('%Y', 'yyyy').replace('%m', 'mm').replace('%d', 'dd')
+        date_format = settings.DATE_INPUT_FORMATS[0].replace('%Y', 'yyyy').replace('%m', 'mm').replace('%d', 'dd')
+        dictsettings['date_format'] = date_format
         # Languages
         dictsettings['languages'] = dict(available=dict(app_settings['TRANSLATED_LANGUAGES']),
                                          default=app_settings['LANGUAGE_CODE'])
@@ -144,7 +120,6 @@ class JSSettings(JSONResponseMixin, TemplateView):
 
 
 class BaseListView(FilterListMixin, ModelViewMixin):
-
     columns = None
 
     def __init__(self, *args, **kwargs):
@@ -178,7 +153,7 @@ def map_screenshot(request):
     """
     try:
         printcontext = request.POST['printcontext']
-        assert len(printcontext) < 512, "Print context is way too big."
+        assert len(printcontext) < 2048, "Print context is way too big."
 
         # Prepare context, extract and add infos
         context = json.loads(printcontext)
@@ -187,7 +162,7 @@ def map_screenshot(request):
         map_url = request.build_absolute_uri(map_url)
         context['print'] = True
         printcontext = json.dumps(context)
-        contextencoded = urllib2.quote(printcontext)
+        contextencoded = quote(printcontext)
         map_url += '?context=%s' % contextencoded
         logger.debug("Capture %s" % map_url)
 
@@ -200,9 +175,9 @@ def map_screenshot(request):
         response['Content-Disposition'] = 'attachment; filename=%s.png' % datetime.now().strftime('%Y%m%d-%H%M%S')
         return response
 
-    except Exception, e:
-        logger.exception(e)
-        return HttpResponseBadRequest(e)
+    except Exception as exc:
+        logger.exception(exc)
+        return HttpResponseBadRequest(exc)
 
 
 @require_http_methods(["POST"])
@@ -212,7 +187,7 @@ def history_delete(request, path=None):
     path = request.POST.get('path', path)
     if path:
         history = request.session.get('history')
-    if history:
-        history = [h for h in history if h['path'] != path]
-        request.session['history'] = history
+        if history:
+            history = [h for h in history if h['path'] != path]
+            request.session['history'] = history
     return HttpResponse()
