@@ -1,4 +1,5 @@
 import os
+import json
 import logging
 from datetime import datetime
 
@@ -12,7 +13,7 @@ from django.views.generic.detail import DetailView
 from django.views.generic import View
 from django.views.generic.edit import CreateView, UpdateView, DeleteView
 from django.views.generic.list import ListView
-from django.template.base import TemplateDoesNotExist
+from django.template.exceptions import TemplateDoesNotExist
 from django.template.defaultfilters import slugify
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
@@ -120,7 +121,7 @@ class MapEntityFormat(BaseListView, ListView):
             return HttpResponseBadRequest()
 
         filename = '%s-%s-list' % (datetime.now().strftime('%Y%m%d-%H%M'),
-                                   str(slugify(unicode(self.get_model()._meta.verbose_name))))
+                                   str(slugify(u"{}".format(self.get_model()._meta.verbose_name))))
         filename += '.%s' % extensions.get(fmt_str, fmt_str)
         response = formatter(request=self.request, context=context, **response_kwargs)
         response['Content-Disposition'] = 'attachment; filename=%s' % filename
@@ -128,14 +129,14 @@ class MapEntityFormat(BaseListView, ListView):
 
     def csv_view(self, request, context, **kwargs):
         serializer = mapentity_serializers.CSVSerializer()
-        response = HttpResponse(mimetype='text/csv')
+        response = HttpResponse(content_type='text/csv')
         serializer.serialize(queryset=self.get_queryset(), stream=response,
                              model=self.get_model(), fields=self.columns, ensure_ascii=True)
         return response
 
     def shape_view(self, request, context, **kwargs):
         serializer = mapentity_serializers.ZipShapeSerializer()
-        response = HttpResponse(mimetype='application/zip')
+        response = HttpResponse(content_type='application/zip')
         serializer.serialize(queryset=self.get_queryset(), model=self.get_model(),
                              stream=response, fields=self.columns)
         response['Content-length'] = str(len(response.content))
@@ -143,7 +144,7 @@ class MapEntityFormat(BaseListView, ListView):
 
     def gpx_view(self, request, context, **kwargs):
         serializer = mapentity_serializers.GPXSerializer()
-        response = HttpResponse(mimetype='application/gpx+xml')
+        response = HttpResponse(content_type='application/gpx+xml')
         serializer.serialize(self.get_queryset(), model=self.get_model(), stream=response,
                              geom_field=app_settings['GEOM_FIELD_NAME'])
         return response
@@ -170,7 +171,7 @@ class MapEntityMapImage(ModelViewMixin, DetailView):
         if settings.DEBUG or not app_settings['SENDFILE_HTTP_HEADER']:
             response = static.serve(self.request, path, settings.MEDIA_ROOT)
         else:
-            response = HttpResponse(mimetype='image/png')
+            response = HttpResponse(content_type='image/png')
             response[app_settings['SENDFILE_HTTP_HEADER']] = os.path.join(settings.MEDIA_URL_SECURE, path)
         return response
 
@@ -197,32 +198,49 @@ class MapEntityDocumentBase(ModelViewMixin, DetailView):
         context = super(MapEntityDocumentBase, self).get_context_data(**kwargs)
         context['datetime'] = datetime.now()
         context['objecticon'] = os.path.join(settings.STATIC_ROOT, self.get_entity().icon_big)
-        context['STATIC_URL'] = self.request.build_absolute_uri(settings.STATIC_URL)[:-1]
-        context['MEDIA_URL'] = self.request.build_absolute_uri(settings.MEDIA_URL)[:-1]
-        context['MEDIA_ROOT'] = settings.MEDIA_ROOT + '/'
+        context['logo_path'] = os.path.join(settings.MEDIA_ROOT, 'upload/logo-header.png')
+        if not os.path.exists(context['logo_path']):
+            context['logo_path'] = os.path.join(settings.STATIC_ROOT, 'images/logo-header.png')
+        context['STATIC_URL'] = self.request.build_absolute_uri(settings.STATIC_URL)
+        context['STATIC_ROOT'] = settings.STATIC_ROOT
+        context['MEDIA_URL'] = self.request.build_absolute_uri(settings.MEDIA_URL)
+        context['MEDIA_ROOT'] = settings.MEDIA_ROOT
         return context
 
 
-class MapEntityDocumentWeasyprint(MapEntityDocumentBase, PDFTemplateResponseMixin):
+class MapEntityWeasyprint(MapEntityDocumentBase):
 
     def __init__(self, *args, **kwargs):
-        super(MapEntityDocumentWeasyprint, self).__init__(*args, **kwargs)
+        super(MapEntityWeasyprint, self).__init__(*args, **kwargs)
 
         suffix = suffix_for(self.template_name_suffix, "_pdf", "html")
         self.template_name = smart_get_template(self.model, suffix)
         if not self.template_name:
-            raise TemplateDoesNotExist(name_for(self.model._meta.app_label, self.model._meta.object_name.lower(), suffix))
-        self.template_attributes = smart_get_template(self.model, suffix_for(self.template_name_suffix, "_attributes", "html"))
+            raise TemplateDoesNotExist(name_for(self.model._meta.app_label,
+                                                self.model._meta.object_name.lower(), suffix))
+        self.template_attributes = smart_get_template(self.model, suffix_for(self.template_name_suffix,
+                                                                             "_attributes", "html"))
         self.template_css = smart_get_template(self.model, suffix_for(self.template_name_suffix, "_pdf", "css"))
 
     def get_context_data(self, **kwargs):
-        context = super(MapEntityDocumentWeasyprint, self).get_context_data(**kwargs)
-        context['map_url'] = self.get_object().get_map_image_url()
+        context = super(MapEntityWeasyprint, self).get_context_data(**kwargs)
+        context['map_path'] = self.get_object().get_map_image_path()
         context['template_attributes'] = self.template_attributes
         context['template_css'] = self.template_css
         return context
 
 
+class MapEntityDocumentWeasyprint(MapEntityWeasyprint, PDFTemplateResponseMixin):
+    pass
+
+
+class MapEntityMarkupWeasyprint(MapEntityWeasyprint):
+
+    @classmethod
+    def get_entity_kind(cls):
+        return mapentity_models.ENTITY_MARKUP
+
+
 class MapEntityDocumentOdt(MapEntityDocumentBase):
     response_class = OdtTemplateResponse
     with_html_attributes = True
@@ -233,7 +251,8 @@ class MapEntityDocumentOdt(MapEntityDocumentBase):
         suffix = suffix_for(self.template_name_suffix, "", "odt")
         self.template_name = smart_get_template(self.model, suffix)
         if not self.template_name:
-            raise TemplateDoesNotExist(name_for(self.model._meta.app_label, self.model._meta.object_name.lower(), suffix))
+            raise TemplateDoesNotExist(name_for(self.model._meta.app_label,
+                                                self.model._meta.object_name.lower(), suffix))
 
     def get_context_data(self, **kwargs):
         context = super(MapEntityDocumentOdt, self).get_context_data(**kwargs)
@@ -242,6 +261,7 @@ class MapEntityDocumentOdt(MapEntityDocumentBase):
         context['_'] = _
         return context
 
+
 if app_settings['MAPENTITY_WEASYPRINT']:
     MapEntityDocument = MapEntityDocumentWeasyprint
 else:
@@ -284,18 +304,14 @@ class Convert(View):
         return response
 
     def request_headers(self):
-        """Retrieves the original HTTP headers of this view request.
+        """Retrieves the original Accept-Language header of this view request.
         Django converts header names to upper-case with underscores.
 
         See http://stackoverflow.com/questions/3889769/get-all-request-headers-in-django
         """
-        excluded = ['HTTP_COOKIE', 'HTTP_HOST']
-        headers = []
-        for name, value in self.request.META.items():
-            if name.startswith('HTTP_') and name not in excluded:
-                realname = name.replace('HTTP_', '').replace('_', '-').title()
-                headers.append((realname, value))
-        return dict(headers)
+        if 'HTTP_ACCEPT_LANGUAGE' not in self.request.META:
+            return {}
+        return {'Accept-Language': self.request.META['HTTP_ACCEPT_LANGUAGE']}
 
 
 class DocumentConvert(Convert, DetailView):
@@ -369,7 +385,7 @@ class MapEntityDetail(ModelViewMixin, DetailView):
         return default + ['mapentity/mapentity_detail.html']
 
     def get_title(self):
-        return unicode(self.get_object())
+        return u"{}".format(self.get_object())
 
     @view_permission_required(login_url=mapentity_models.ENTITY_LIST)
     @save_history()
@@ -394,6 +410,11 @@ class MapEntityDetail(ModelViewMixin, DetailView):
         context['attachment_form_class'] = AttachmentForm
         context['template_attributes'] = self.template_attributes
         context['mapentity_weasyprint'] = app_settings['MAPENTITY_WEASYPRINT']
+        if 'context' in self.request.GET:
+            mapcontext = json.loads(self.request.GET['context'])
+            if 'mapsize' in mapcontext:
+                context['mapwidth'] = int(mapcontext['mapsize']['width'])
+                context['mapheight'] = int(mapcontext['mapsize']['height'])
 
         return context
 
