@@ -1,8 +1,8 @@
 from django.template.loader import render_to_string
 from django.forms import widgets as django_widgets
-
+from django.utils import six
 from leaflet.forms.widgets import LeafletWidget
-import floppyforms as forms
+from django import forms
 
 from .settings import API_SRID
 from .helpers import wkt_to_geom
@@ -30,7 +30,7 @@ class HiddenGeometryWidget(django_widgets.HiddenInput):
         """
         Before serialization, reprojects to API_SRID
         """
-        if value and not isinstance(value, basestring):
+        if value and not isinstance(value, six.string_types):
             value.transform(API_SRID)
         return value
 
